@@ -22,7 +22,7 @@
 #' @param bin Rule for constructing intervals when a partition parameter (int, 
 #' nclass or size) is not given. Default is Sturge's rule (Sturges, 1926). Other
 #' option is Freedman-Diaconis method (Freedman and Diaconis, 1981).
-#' @param method Correlogram method. Could be I for Moran's I, C for Geary's C
+#' @param method Correlogram method. It can be I for Moran's I, C for Geary's C
 #' and CC for Bivariate Moran's Ixy. 
 #' If method = "CC", the program computes for the first interval (d = 0)
 #' the corresponding P-value and CI with \code{\link[stats]{cor.test}}.
@@ -31,14 +31,16 @@
 #' resampling and the associated confidence intervals of the null hypothesis.
 #'  If test = "permutation" (default) a permutation test is made and the P-values 
 #'  are computed. 	
-#' @param alpha Value for alpha. Default alpha = 0.05.
+#' @param alpha Value for alpha (significance level). Default alpha = 0.05.
 #' @param alternative The alternative hypothesis. If "auto" is selected (default) the
 #' program determines the alternative hypothesis.
 #' Other options are: "two.sided", "greater" and "less".	
-#' @param adjust P-values correction method for multiple tests 
-#' passed to \code{\link[stats]{p.adjust}}. Defalut is "holm".
-#' @param sequential Should be performed a Holm-Bonberroni (Legendre and Legendre, 2012) 
-#' adjustment of P-values? Defalult TRUE.
+#' @param adjust P-values correction method for multiple tests. 
+#' The selected method is passed as argument to \code{\link[stats]{p.adjust}} (defalut = "holm").
+#' For bearing correlograms, the corrections (and permutation tests) are performed for individual correlograms 
+#' of fixed variables (i.e.,  angles fixed [distances variable] or distances fixed [angles variable]). 
+#' @param sequential Should a Holm-Bonberroni correction of P-values (Legendre and Legendre, 2012) be performed?
+#' Defalult TRUE (only available for omnidirectional correlograms or correlograms for fixed angles). 
 #' @param include.zero Should be included the distance = 0 in cross correlograms 
 #' (i.e., the intra- individual correlation)?. Defalut TRUE.
 #' @param cummulative Should be construced a cummulative correlogram?.
@@ -286,7 +288,7 @@
 #' Sturges  H. 1926. The choice of a class interval. Journal of the American 
 #' Statistical Association, 21: 65-66.
 #' 
-#' @author Leandro Roser \email{leandroroser@@ege.fcen.uba.ar}
+#' @author Leandro Roser \email{learoser@@gmail.com}
 #' 
 #' @export
 
@@ -304,8 +306,8 @@ setGeneric("eco.correlog",
                     alpha = 0.05,
                     alternative = c("auto", "two.sided", 
                                     "greater", "less"),
-                    adjust = "holm",
-                    sequential = TRUE, 
+                    adjust = "holm", 
+                    sequential =  ifelse((as.deg), FALSE, TRUE), 
                     include.zero = TRUE,
                     cummulative = FALSE,
                     bin = c("sturges", "FD"),
@@ -329,6 +331,10 @@ setGeneric("eco.correlog",
                stop("Only permutation test is available for bearing correlograms with degrees format output")
              }
              
+             if(length(angle) > 1 && as.deg && sequential) {
+               stop("Sequential correction of P values is only available for correlograms with fixed angles")
+             }
+             
              
              Z.class <- class(Z)
              if(Z.class != "numeric" & Z.class != "integer" &  Z.class != "matrix" & Z.class != "data.frame") {
